%define major	0
%define libname	%mklibname metis %{major}
%define devname %mklibname metis -d

Name:		metis
Version:	5.1.0.3
Release:	%mkrel 3
Summary:	Serial Graph Partitioning and Fill-reducing Matrix Ordering
License:	ASL 2.0 and BSD and LGPLv2+
Group:		Sciences/Other
URL:		http://glaros.dtc.umn.edu/gkhome/views/metis
Source0:	https://github.com/scivision/METIS/archive/v%{version}/METIS-%{version}.tar.gz
## This patch sets up libmetis soname of libmetis
Patch0:		%{name}-libmetis.patch

## This patch sets up shared GKlib library
Patch1:		%{name}-shared-GKlib.patch

## This patch sets up GKREGEX, GKRAND, libsuffix options to the Makefiles
Patch3:		%{name}-GKREGEX-GKRAND-LIBSUFFIX-fix.patch

Patch5:		%{name}-pcre2.patch

BuildRequires:	cmake >= 2.8
%ifarch aarch64 x86_64
BuildRequires:	openmpi-devel
%endif
BuildRequires:	pkgconfig(libpcre2-posix)
BuildRequires:	help2man
BuildRequires:	libgomp-devel

%description
METIS is a set of serial programs for partitioning graphs,
partitioning finite element meshes, and producing fill reducing
orderings for sparse matrices.

The algorithms implemented in METIS are based on the multilevel
recursive-bisection, multilevel k-way, and multi-constraint
partitioning schemes developed in our lab.

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n %{devname}
Summary:	The Metis headers and development-related files
Group:		Sciences/Other
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Conflicts:      libscotch-metis-devel

%description -n %{devname}
Header and library files of Metis.

%prep
%setup -q -n METIS-%{version}
%patch -P 0 -p0
%patch -P 1 -p0
%patch -P 3 -p0
%patch -P 5 -p0

%build
# By default, metis.h uses 32-bit integer and real. Each can be independently set
# to 32 or 64 bits like:
#cmake -Bbuild -Dintsize=64 -Drealsize=64

# Build metis
%cmake \
	-DCMAKE_C_COMPILER=%{_bindir}/gcc \
	-DCMAKE_CXX_COMPILER=%{_bindir}/g++ \
	%ifarch aarch64 x86_64
	-Dintsize=64 -Drealsize=64 \
	%endif
	-DOPENMP=%{_includedir}/openmpi \
	-DPCRE:BOOL=ON \
	-DCMAKE_CXX_FLAGS="%{optflags} -fopenmp -pthread" \
	-DCMAKE_C_FLAGS="%{optflags} -fopenmp -pthread -lpcre2-posix" \
%cmake_build

%check
cp -p %{buildroot}%{_bindir}/*metis src/graphs/
cp -p %{buildroot}%{_bindir}/graphchk src/graphs/
cd src/graphs
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./ndmetis mdual.graph
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./mpmetis metis.mesh 2
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./gpmetis test.mgraph 4
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./gpmetis copter2.graph 4
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$LD_LIBRARY_PATH ./graphchk 4elt.graph
cd ../../
%ctest --test-dir ./
cd ../

%install
%cmake_install

## Generate manpages from binaries
LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" -n "Partitions a graph into a specified number of parts." \
 -N --output="gpmetis.1" --no-discard-stderr --help-option="-help" %{buildroot}%{_bindir}/gpmetis

LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" \
 -n "Computes a fill-reducing ordering of the vertices of the graph using multilevel nested dissection." \
 -N --output="ndmetis.1" --no-discard-stderr --help-option="-help" %{buildroot}%{_bindir}/ndmetis

LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" -n "Partitions a mesh into a specified number of parts." \
 -N --output="mpmetis.1" --no-discard-stderr --help-option="-help" %{buildroot}%{_bindir}/mpmetis

LD_PRELOAD=%{buildroot}%{_libdir}/lib%{name}.so.%{major} \
help2man --version-string="%{version}" -n "Converts a mesh into a graph that is compatible with METIS." \
 -N --output="m2gmetis.1" --no-discard-stderr -h "-help" %{buildroot}%{_bindir}/m2gmetis

mkdir -p %{buildroot}%{_mandir}/man1
mv *.1 %{buildroot}%{_mandir}/man1

%files
%doc src/Changelog src/manual/manual.pdf
%license src/LICENSE.txt
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%license src/LICENSE.txt
%{_libdir}/lib%{name}.so.%{major}

%files -n %{devname}
%doc src/Changelog
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 5.1.0.3-3.mga10
+ Revision: 2232535
- Mageia 10 Mass Rebuild

* Sun Dec 22 2024 daviddavid <daviddavid> 5.1.0.3-2.mga10
+ Revision: 2128639
- openmpi is only available on 64bit
+ pterjan <pterjan>
- Rebuild for patchN deprecation

* Sat Feb 17 2024 daviddavid <daviddavid> 5.1.0.3-1.mga10
+ Revision: 2042086
- new version: 5.1.0.3 (New source code archive at https://github.com/scivision/METIS)
- switch to pcre2

* Thu Mar 31 2022 umeabot <umeabot> 5.1.0-9.mga9
+ Revision: 1837022
- Mageia 9 Mass Rebuild

* Fri Aug 27 2021 eatdirt <eatdirt> 5.1.0-8.mga9
+ Revision: 1742848
- Add conflicts with scotch-metis-devel

* Fri Feb 14 2020 umeabot <umeabot> 5.1.0-7.mga8
+ Revision: 1516905
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 5.1.0-6.mga7
+ Revision: 1299526
- Mageia 7 Mass Rebuild

* Mon Feb 08 2016 umeabot <umeabot> 5.1.0-5.mga6
+ Revision: 943917
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 5.1.0-4.mga5
+ Revision: 746346
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 5.1.0-3.mga5
+ Revision: 727243
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 5.1.0-2.mga5
+ Revision: 682371
- Mageia 5 Mass Rebuild

* Sat Jun 28 2014 wally <wally> 5.1.0-1.mga5
+ Revision: 640881
- fix libification

* Tue Nov 26 2013 philippem <philippem> 5.1.0-0.mga4
+ Revision: 553614
- change group
- fix linking issues and buildrequires
- imported package metis

